==> ejc-sealm-impl-3.0.0-20220607.093010-85-sources.jar: com/ejianc/business/sealm/bean/YzsqEntity.java <==
package com.ejianc.business.sealm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 印章申请
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_yzsq")
public class YzsqEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="apply_organ_id")
    private java.lang.Long applyOrganId; // 申请单位id
    @TableField(value="apply_organ_name")
    private java.lang.String applyOrganName; // 申请单位名称
    @TableField(value="yzlb_id")
    private java.lang.Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private java.lang.String yzlbName; // 印章类别名称
    @TableField(value="yzjb_id")
    private java.lang.Long yzjbId; // 印章级别id
    @TableField(value="yzjb_name")
    private java.lang.String yzjbName; // 印章级别名称
    @TableField(value="yylx_id")
    private java.lang.Long yylxId; // 用印类型id
    @TableField(value="yylx_name")
    private java.lang.String yylxName; // 用印类型名称
    @TableField(value="kzzy")
    private java.lang.String kzzy; // 刻章字样
    @TableField(value="apply_reason")
    private java.lang.String applyReason; // 申请事由
    @TableField(value="remark")
    private java.lang.String remark; // 备注
    @TableField(value="yzkz_state")
    private java.lang.Integer yzkzState; // 印章刻制状态(默认是0，0表示未刻制，1表示已刻制)
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 编制人
    @TableField(value="operator_id")
    private java.lang.Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人姓名
    @TableField(value="operator_tel")
    private java.lang.String operatorTel; // 经办人联系方式
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="dwfzr_id")
    private Long dwfzrId; // 单位负责人
    @TableField(value="dwfzr_name")
    private String dwfzrName; // 单位负责人名称
    @TableField(value="ssxmb_id")
    private Long ssxmbId; // 所属项目经理部
    @TableField(value="ssxmb_name")
    private String ssxmbName; // 所属项目经理部名称


    public Long getSsxmbId() {
        return ssxmbId;
    }

    public void setSsxmbId(Long ssxmbId) {
        this.ssxmbId = ssxmbId;
    }

    public String getSsxmbName() {
        return ssxmbName;
    }

    public void setSsxmbName(String ssxmbName) {
        this.ssxmbName = ssxmbName;
    }

    public Long getDwfzrId() {
        return dwfzrId;
    }

    public void setDwfzrId(Long dwfzrId) {
        this.dwfzrId = dwfzrId;
    }

    public String getDwfzrName() {
        return dwfzrName;
    }

    public void setDwfzrName(String dwfzrName) {
        this.dwfzrName = dwfzrName;
    }

    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 申请单位id
     */
    public java.lang.Long getApplyOrganId() {
        return applyOrganId;
    }

    /**
     * 申请单位id
     */
    public void setApplyOrganId(java.lang.Long applyOrganId) {
        this.applyOrganId = applyOrganId;
    }
    /**
     * 申请单位名称
     */
    public java.lang.String getApplyOrganName() {
        return applyOrganName;
    }

    /**
     * 申请单位名称
     */
    public void setApplyOrganName(java.lang.String applyOrganName) {
        this.applyOrganName = applyOrganName;
    }
    /**
     * 印章类别id
     */
    public java.lang.Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    public void setYzlbId(java.lang.Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public java.lang.String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(java.lang.String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    public java.lang.Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    public void setYzjbId(java.lang.Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public java.lang.String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(java.lang.String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    public java.lang.Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    public void setYylxId(java.lang.Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public java.lang.String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(java.lang.String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public java.lang.String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(java.lang.String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 申请事由
     */
    public java.lang.String getApplyReason() {
        return applyReason;
    }

    /**
     * 申请事由
     */
    public void setApplyReason(java.lang.String applyReason) {
        this.applyReason = applyReason;
    }
    /**
     * 备注
     */
    public java.lang.String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(java.lang.String remark) {
        this.remark = remark;
    }
    /**
     * 印章刻制状态(默认是0，0表示未刻制，1表示已刻制)
     */
    public java.lang.Integer getYzkzState() {
        return yzkzState;
    }

    /**
     * 印章刻制状态(默认是0，0表示未刻制，1表示已刻制)
     */
    public void setYzkzState(java.lang.Integer yzkzState) {
        this.yzkzState = yzkzState;
    }
    /**
     * 组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 经办人ID
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人ID
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人姓名
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 经办人联系方式
     */
    public java.lang.String getOperatorTel() {
        return operatorTel;
    }

    /**
     * 经办人联系方式
     */
    public void setOperatorTel(java.lang.String operatorTel) {
        this.operatorTel = operatorTel;
    }

    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

}

==> ejc-sealm-impl-3.0.0-20230210.024619-131-sources.jar: com/ejianc/business/sealm/bean/YzsqEntity.java <==
package com.ejianc.business.sealm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 印章申请
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_yzsq")
public class YzsqEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="apply_organ_id")
    private java.lang.Long applyOrganId; // 申请单位id
    @TableField(value="apply_organ_name")
    private java.lang.String applyOrganName; // 申请单位名称
    @TableField(value="yzlb_id")
    private java.lang.Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private java.lang.String yzlbName; // 印章类别名称
    @TableField(value="yzjb_id")
    private java.lang.Long yzjbId; // 印章级别id
    @TableField(value="yzjb_name")
    private java.lang.String yzjbName; // 印章级别名称
    @TableField(value="yylx_id")
    private java.lang.Long yylxId; // 用印类型id
    @TableField(value="yylx_name")
    private java.lang.String yylxName; // 用印类型名称
    @TableField(value="kzzy")
    private java.lang.String kzzy; // 刻章字样
    @TableField(value="apply_reason")
    private java.lang.String applyReason; // 申请事由
    @TableField(value="remark")
    private java.lang.String remark; // 备注
    @TableField(value="yzkz_state")
    private java.lang.Integer yzkzState; // 印章刻制状态(默认是0，0表示未刻制，1表示已刻制)
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 编制人
    @TableField(value="operator_id")
    private java.lang.Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人姓名
    @TableField(value="operator_tel")
    private java.lang.String operatorTel; // 经办人联系方式
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="dwfzr_id")
    private Long dwfzrId; // 单位负责人
    @TableField(value="dwfzr_name")
    private String dwfzrName; // 单位负责人名称
    @TableField(value="ssxmb_id")
    private Long ssxmbId; // 所属项目经理部
    @TableField(value="ssxmb_name")
    private String ssxmbName; // 所属项目经理部名称
    @TableField(value="sftbkdzyz")
    private String sftbkdzyz; // 是否同步刻电子印章
    @TableField(value="sftbfzyky")
    private String sftbfzyky; // 是否同步封装印控仪


    public String getSftbkdzyz() {
        return sftbkdzyz;
    }

    public void setSftbkdzyz(String sftbkdzyz) {
        this.sftbkdzyz = sftbkdzyz;
    }

    public String getSftbfzyky() {
        return sftbfzyky;
    }

    public void setSftbfzyky(String sftbfzyky) {
        this.sftbfzyky = sftbfzyky;
    }

    public Long getSsxmbId() {
        return ssxmbId;
    }

    public void setSsxmbId(Long ssxmbId) {
        this.ssxmbId = ssxmbId;
    }

    public String getSsxmbName() {
        return ssxmbName;
    }

    public void setSsxmbName(String ssxmbName) {
        this.ssxmbName = ssxmbName;
    }

    public Long getDwfzrId() {
        return dwfzrId;
    }

    public void setDwfzrId(Long dwfzrId) {
        this.dwfzrId = dwfzrId;
    }

    public String getDwfzrName() {
        return dwfzrName;
    }

    public void setDwfzrName(String dwfzrName) {
        this.dwfzrName = dwfzrName;
    }

    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 申请单位id
     */
    public java.lang.Long getApplyOrganId() {
        return applyOrganId;
    }

    /**
     * 申请单位id
     */
    public void setApplyOrganId(java.lang.Long applyOrganId) {
        this.applyOrganId = applyOrganId;
    }
    /**
     * 申请单位名称
     */
    public java.lang.String getApplyOrganName() {
        return applyOrganName;
    }

    /**
     * 申请单位名称
     */
    public void setApplyOrganName(java.lang.String applyOrganName) {
        this.applyOrganName = applyOrganName;
    }
    /**
     * 印章类别id
     */
    public java.lang.Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    public void setYzlbId(java.lang.Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public java.lang.String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(java.lang.String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    public java.lang.Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    public void setYzjbId(java.lang.Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public java.lang.String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(java.lang.String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    public java.lang.Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    public void setYylxId(java.lang.Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public java.lang.String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(java.lang.String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public java.lang.String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(java.lang.String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 申请事由
     */
    public java.lang.String getApplyReason() {
        return applyReason;
    }

    /**
     * 申请事由
     */
    public void setApplyReason(java.lang.String applyReason) {
        this.applyReason = applyReason;
    }
    /**
     * 备注
     */
    public java.lang.String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(java.lang.String remark) {
        this.remark = remark;
    }
    /**
     * 印章刻制状态(默认是0，0表示未刻制，1表示已刻制)
     */
    public java.lang.Integer getYzkzState() {
        return yzkzState;
    }

    /**
     * 印章刻制状态(默认是0，0表示未刻制，1表示已刻制)
     */
    public void setYzkzState(java.lang.Integer yzkzState) {
        this.yzkzState = yzkzState;
    }
    /**
     * 组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 经办人ID
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人ID
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人姓名
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 经办人联系方式
     */
    public java.lang.String getOperatorTel() {
        return operatorTel;
    }

    /**
     * 经办人联系方式
     */
    public void setOperatorTel(java.lang.String operatorTel) {
        this.operatorTel = operatorTel;
    }

    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

}
